/*
////////////////////////////////////////////////////////////////////////////////
// Licensed Materials - Use restricted. For use in compiling interfaces to
// IBM Rational TestManager.
// (c) Copyright IBM Corporation 2006.  All Rights Reserved.
//
//	FILENAME:		proxutil.h
//	DESCRIPTION:	implementation of Virtual User API Utility Funcs
//
//	REVISION HISTORY
//	PROGRAMMER		DATE		REVISION
//	============================================================================
//
//	SMC				12/05/98	add ProxyGetdwTotal[Calls|Bytes]
//	SMC				12/01/98	use C naming conventions
//	DJM				11/06/98	initial product version
//
////////////////////////////////////////////////////////////////////////////////
*/


#ifndef __INCLUDE_PROXUTIL_H
#define __INCLUDE_PROXUTIL_H	1	


#define PROXY_INVALID_TICKET		0
#define PROXY_INVALID_TIMESTAMP		0

#define STR_PROXY_UTIL_NAME		_T("sqa7vutl.dll")


#ifdef __cplusplus
extern "C" {  
#endif


typedef int (WINAPI *PROXYRECORDSTARTFARPROC)(LPTSTR);
typedef int (WINAPI *PROXYRECORDENDFARPROC)(void);


//
// internal functions 
//

BOOL InitializeVutl(void);
BOOL CleanupVutl(void);

BOOL OptexConstructor(DWORD dwSpinCount, DWORD dwTimeout);
void OptexDestructor(void);
void OptexSetSpinCount(DWORD dwSpinCount);
void OptexSetTimeout(DWORD dwTimeout);

BOOL OptexEnter(void);
void OptexLeave(void);
BOOL OptexTryEnter(void);

BOOL ProxyLockMemBufferConstructor(void);
BOOL ProxyLockMemBufferDestructor(void);
BOOL ProxyLockMemBufferResize(DWORD dwSize);

BOOL CreateWchFileAndMap(void);
BOOL DeleteWchFileAndMap(void);
BOOL ResizeWchFileMap(void);

BOOL InitializeWchFile(void);
BOOL CleanupWchFile(void);
BOOL CleanupWchFileMap(void);

BOOL LockWchFile(void);
BOOL UnlockWchFile(void);

DWORD WINAPI ProxyEventThread(LPVOID vp);

BOOL NotifyAllProcessesToMapAndWait(void);
BOOL NotifyAllProcessesToUnmapAndWait(void);

BOOL NotifyAllProcessesToStartRecordingAndWait(void);
BOOL NotifyAllProcessesToStopRecordingAndWait(void);

BOOL IsWinNT4ServicePack4( void ) ;

//
// exported functions
//

// used by Proxies
DWORD ProxyGetAssignedLibraryID(TCHAR*);
DWORD ProxyGetTicket(void);
DWORD ProxyGetTimeStamp(void);
VOID *ProxyLock(int iTicket,
				DWORD dwTime,
				int iLib_ID,
				int iAPI_ID,
				int iPacketType,
				int iSize);
VOID **ProxyLockNew(DWORD dwTicket,
				DWORD dwTime,
				int iLib_ID,
				int iAPI_ID,
				int iPacketType,
				int iSize);
BOOL ProxySetCustomLibNames(TCHAR* szProtocolNames);
void ProxyUnlock(DWORD dwTime);
int	 ProxyWriteBlock(LPVOID lpBlock, int iNumBytes);
int ProxyExceptionHandler(int iLib_ID, int iAPI_ID);
HINSTANCE GetRealApiFuncAddr();
void UnGetRealApiFuncAddr();
void ProxyLockLowAPI(int);
void ProxyUnLockLowAPI(int);
int ProxyIsLockedOut(int);

// used by RVS
BOOL ProxyRecordStart(LPTSTR path);
int ProxyRecordEnd(void);

// used by VRC
LONG ProxyGetdwTotalCalls(void);
LONG ProxyGetdwTotalBytes(void);


#ifdef __cplusplus
}  // extern "C"
#endif


#endif /* __INCLUDE_PROXUTIL_H */
